@@ -6,13 +6,15 @@ BEGIN {
   $Dist::Zilla::Plugin::MetaData::BuiltWith::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::MetaData::BuiltWith::VERSION = '0.02000100';
+  $Dist::Zilla::Plugin::MetaData::BuiltWith::VERSION = '0.02000101';
 }
 
 # ABSTRACT: Report what versions of things your distribution was built against
 
 
-use Dist::Zilla::Util::EmulatePhase 0.01000101 qw( get_prereqs );
+use Dist::Zilla::Util::EmulatePhase;
+use Readonly;
+Readonly my $MIN_EMULATE_PHASE => '0.01000101';
 use Moose 2.0;
 use Class::Load qw( load_optional_class );
 use MooseX::Types::Moose (qw( ArrayRef Bool Str ));
@@ -116,7 +118,10 @@ sub _get_prereq_modnames {
 
   my $modnames = {};
 
-  my $prereqs = get_prereqs( { zilla => $self->zilla } )->as_string_hash;
+  if ( defined $Dist::Zilla::Util::EmulatePhase::VERSION ) {
+    Dist::Zilla::Util::EmulatePhase->VERSION($MIN_EMULATE_PHASE);
+  }
+  my $prereqs = Dist::Zilla::Util::EmulatePhase::get_prereqs( { zilla => $self->zilla } )->as_string_hash;
   if ( not %{$prereqs} ) {
     $self->log(q{WARNING: No prereqs were found, probably a bug});
     return [];
@@ -235,7 +240,7 @@ Dist::Zilla::Plugin::MetaData::BuiltWith - Report what versions of things your d
 
 =head1 VERSION
 
-version 0.02000100
+version 0.02000101
 
 =head1 SYNOPSIS
 
